# TRXASprefitpack_info

Access the document of TRXASprefitpack

```{warning}
This utility is deprecated, will be remove in version 0.5
```

* usage: TRXASprefitpack_info.py [-h] [-fn FUN_NAME]

* optional arguments:
  * -h, --help            show this help message and exit
  * -fn FUN_NAME, --fun_name FUN_NAME       function name


